locals {
  HOST   = "example.local"
  TARGET = "https://example.com/path"
}

job "domainredirect" {
  datacenters = ["dc1"]
  type = "service"

  group "domainredirect" {
    count = 1

    network {
      port "http" {
        to = 8080
      }
    }

    service {
      name = "domainredirect"
      provider = "consul"
      port = "http"

      tags = [
        "traefik.enable=true", 
        "traefik.http.routers.domainredirect.tls=true",
        "traefik.http.routers.domainredirect.entrypoints=websecure",
        "traefik.http.routers.domainredirect.rule=Host(`${local.HOST}`)",
        ]

      check {
        type = "http"
        path = "/health"
        interval = "10s"
        timeout = "2s"
      }
    }

    task "domainredirect" {
      driver = "docker"

      config {
        image = "git.cbraaten.dev/caleb/domainredirect:latest"
        ports = ["http"]
      }

      env {
        REDIRECT_TARGET = local.TARGET
      }
    }
  }
}
